@@ -1,13 +1,13 @@
 """
 matplotlib implementation of the gki kernel class
 
-$Id: GkiMpl.py 1742 2012-05-23 13:45:59Z sontag $
+$Id$
 """
 
 from __future__ import division # confidence high
 
 import math, sys, numpy, os
-import Tkinter as Tki
+import Tkinter as TKNTR
 import matplotlib
 # (done in mca file) matplotlib.use('TkAgg') # set backend
 from matplotlib.lines import Line2D
@@ -63,8 +63,8 @@ class GkiMplKernel(gkitkbase.GkiInteractiveTkBase):
     def makeGWidget(self, width=600, height=420):
 
         """Make the graphics widget.  Also perform some self init."""
-        self.__pf = Tki.Frame(self.top)
-        self.__pf.pack(side=Tki.TOP, fill=Tki.BOTH, expand=1)
+        self.__pf = TKNTR.Frame(self.top)
+        self.__pf.pack(side=TKNTR.TOP, fill=TKNTR.BOTH, expand=1)
         self.__xsz = width
         self.__ysz = height
 
@@ -74,7 +74,7 @@ class GkiMplKernel(gkitkbase.GkiInteractiveTkBase):
         self.__fig.set_facecolor('k') # default to black
 
         self.__mca = mca.MplCanvasAdapter(self, self.__fig, master=self.__pf)
-        self.__mca.pack(side=Tki.TOP, fill=Tki.BOTH, expand=1)
+        self.__mca.pack(side=TKNTR.TOP, fill=TKNTR.BOTH, expand=1)
         self.__mca.gwidgetize(width, height) # Add attrs to the gwidget
         self.gwidget = self.__mca.get_tk_widget()
 
@@ -727,7 +727,7 @@ class tkColorManager:
 
     def setDrawingColor(self, irafColorIndex):
 
-        """Return the specified iraf color usable by Tkinter"""
+        """Return the specified iraf color usable by tkinter"""
         color = self.config.defaultColors[irafColorIndex]
         red = int(255*color[0])
         green = int(255*color[1])
