@@ -1,15 +1,16 @@
 """ Contains Python routines to do special Aqua (OSX) window manipulations
-not possible in Tkinter.  In general, an attempt is made to use the Pyobjc
+not possible in tkinter.  In general, an attempt is made to use the Pyobjc
 bridging package so that compiling another C extension is not needed.
 
-$Id: aqutil.py 1989 2013-05-29 19:59:47Z sontag $
+$Id$
 """
 
 from __future__ import division # confidence high
 
-import os, struct, time, Tkinter
+import os, struct, time
 import objc
 import AppKit
+from stsci.tools.for2to3 import tobytes
 
 
 # Arbitrary module constants for term vs. gui.  0 and negative numbers have
@@ -178,25 +179,26 @@ def __doPyobjcWinInit():
     OSErr  = objc._C_SHT
     OSStat = objc._C_INT
     CGErr  = objc._C_INT
-    INPSN  = 'n^{ProcessSerialNumber=LL}'
-    OUTPSN = 'o^{ProcessSerialNumber=LL}'
-    OUTPID = 'o^_C_ULNG'
-    WARPSIG = 'v{CGPoint=ff}'
+    INPSN  = tobytes('n^{ProcessSerialNumber=LL}')
+    OUTPSN = tobytes('o^{ProcessSerialNumber=LL}')
+#   OUTPID = tobytes('o^_C_ULNG') # invalid as of objc v3.2
+    WARPSIG = tobytes('v{CGPoint=ff}')
     if struct.calcsize("l") > 4: # is 64-bit python
-        WARPSIG = 'v{CGPoint=dd}'
+        WARPSIG = tobytes('v{CGPoint=dd}')
+
 
     FUNCTIONS=[
          # These are public API
          ( u'GetCurrentProcess', OSErr+OUTPSN),
          ( u'GetFrontProcess', OSErr+OUTPSN),
-         ( u'GetProcessPID', OSStat+INPSN+OUTPID),
+#        ( u'GetProcessPID', OSStat+INPSN+OUTPID), # see OUTPID note
          ( u'SetFrontProcess', OSErr+INPSN),
          ( u'CGWarpMouseCursorPosition', WARPSIG),
          ( u'CGMainDisplayID', objc._C_PTR+objc._C_VOID),
          ( u'CGDisplayPixelsHigh', objc._C_ULNG+objc._C_ULNG),
          ( u'CGDisplayHideCursor', CGErr+objc._C_ULNG),
          ( u'CGDisplayShowCursor', CGErr+objc._C_ULNG),
-         # This is undocumented SPI
+         # This is undocumented API
          ( u'CPSSetProcessName', OSErr+INPSN+objc._C_CHARPTR),
          ( u'CPSEnableForegroundOperation', OSErr+INPSN),
     ]
@@ -228,7 +230,7 @@ def __doPyobjcWinInit():
     if err: raise Exception("GetCurrentProcess: "+str(err))
 
     # Set Proc name
-    err = CPSSetProcessName(__thisPSN, 'PyRAF')
+    err = CPSSetProcessName(__thisPSN, tobytes('PyRAF'))
     if err: raise Exception("CPSSetProcessName: "+str(err))
     # Make us a FG app (need to be in order to use SetFrontProcess on us)
     # This must be done unless we are called with pythonw.
@@ -238,9 +240,9 @@ def __doPyobjcWinInit():
         raise Exception("CPSEnableForegroundOperation: "+str(err))
 
     # Get the display's absolute height (pixels).
-    # The next line assumes the Tkinter root window has already been created
+    # The next line assumes the tkinter root window has already been created
     # (and withdrawn), but it may have not yet been.
-#   __screenHeight = Tkinter._default_root.winfo_screenheight()
+#   __screenHeight = tkinter._default_root.winfo_screenheight()
     # So, we will use the less-simple but just as viable CoreGraphics funcs.
     dispIdPtr = CGMainDisplayID() # no need to keep around?
     __screenHeight = CGDisplayPixelsHigh(dispIdPtr)
