@@ -1336,7 +1336,7 @@ def _convFunc(var, value):
         else:
             return str(value)
     elif var.type == "int":
-        if value is None:
+        if value is None or value == "INDEF":  # (matches _INDEFClass object)
             return "INDEF"
         elif isinstance(value,str) and value[:1] == ")":
             # parameter indirection
@@ -1344,7 +1344,7 @@ def _convFunc(var, value):
         else:
             return int(value)
     elif var.type == "real":
-        if value is None:
+        if value is None or value == "INDEF":  # (matches _INDEFClass object)
             return "INDEF"
         elif isinstance(value,str) and value[:1] == ")":
             # parameter indirection
@@ -2416,40 +2416,3 @@ class Tree2Python(GenericASTTraversal, ErrorTracker):
                 return
         self.preorder(node[2])
         self.prune()
-
-if __name__ == "__main__":
-
-    import time
-
-    t0 = time.time()
-
-    # scan file "simple.cl"
-
-    filename = "simple.cl"
-    lines = open(filename).read()
-    scanner = clscan.CLScanner()
-    tokens = scanner.tokenize(lines)
-    t1 = time.time()
-
-    # parse
-    tree = _parser.parse(tokens, fname=filename)
-    tree.filename = filename
-    t2 = time.time()
-
-    # first pass -- get variables
-
-    vars = VarList(tree)
-
-    # second pass -- check all expression types
-    # type info is added to tree
-
-    TypeCheck(tree, vars, '')
-
-    # third pass -- generate python code
-
-    pycode = Tree2Python(tree, vars)
-
-    t3 = time.time()
-
-    print "Scan:", t1-t0, "sec,   Parse:", t2-t1, "sec"
-    print "CodeGen:", t3-t2, "sec"
