@@ -7,11 +7,10 @@
 from __future__ import division # confidence high
 
 # System level modules
-import sys
 import Tkinter as TKNTR # requires 2to3
 
 # Our modules
-from stsci.tools import irafutils, tkrotext
+from stsci.tools import tkrotext
 
 
 def is_USING_X():
@@ -37,9 +36,9 @@ class MsgIOWidget(TKNTR.Frame):
         # Create two sub-frames, one to hold the 1-liner msg I/O, and
         # the other one to hold the whole scrollable history.
         self._nowFrame = TKNTR.Frame(self, bd=2, relief=TKNTR.SUNKEN,
-                                   takefocus=False)
+                                     takefocus=False)
         self._histFrame = TKNTR.Frame(self, bd=2, relief=TKNTR.SUNKEN,
-                                   takefocus=False)
+                                      takefocus=False)
 
         # Put in the expand/collapse button (determine it's sizes)
         self._expBttnHasTxt = True
@@ -55,9 +54,9 @@ class MsgIOWidget(TKNTR.Frame):
                 btxt = ''
                 self._expBttnHasTxt = False
         self._expBttn = TKNTR.Checkbutton(self._nowFrame, command=self._expand,
-                                        padx=px, pady=py,
-                                        text=btxt, indicatoron=0,
-                                        state = TKNTR.DISABLED)
+                                          padx=px, pady=py,
+                                          text=btxt, indicatoron=0,
+                                          state = TKNTR.DISABLED)
         self._expBttn.pack(side=TKNTR.LEFT, padx=3)#, ipadx=0)
 
         # Overlay a label on the frame
@@ -66,23 +65,23 @@ class MsgIOWidget(TKNTR.Frame):
         self._msgLabelMaxWidth = 65 # 70 works but causes plot redraws when
                                     # the history panel is opened/closed
         self._msgLabel = TKNTR.Label(self._nowFrame,
-                                   textvariable=self._msgLabelVar,
-                                   anchor=TKNTR.W,
-                                   justify=TKNTR.LEFT,
-                                   width=self._msgLabelMaxWidth,
-                                   wraplength=width-100,
-                                   takefocus=False)
+                                     textvariable=self._msgLabelVar,
+                                     anchor=TKNTR.W,
+                                     justify=TKNTR.LEFT,
+                                     width=self._msgLabelMaxWidth,
+                                     wraplength=width-100,
+                                     takefocus=False)
         self._msgLabel.pack(side=TKNTR.LEFT,
                             fill=TKNTR.X,
                             expand=False)
         self._msgLabel.bind('<Double-Button-1>', self._lblDblClk)
 
         self._entry = TKNTR.Entry(self._nowFrame,
-                                state=TKNTR.DISABLED,
-                                width=1,
-                                takefocus=False,
-                                relief=TKNTR.FLAT,
-                                highlightthickness=0)
+                                  state=TKNTR.DISABLED,
+                                  width=1,
+                                  takefocus=False,
+                                  relief=TKNTR.FLAT,
+                                  highlightthickness=0)
         self._entry.pack(side=TKNTR.LEFT, fill=TKNTR.X, expand=True)
         self._entry.bind('<Return>', self._enteredText)
         self._entryTyping = TKNTR.BooleanVar()
@@ -99,8 +98,9 @@ class MsgIOWidget(TKNTR.Frame):
         self._histScrl.pack(side=TKNTR.RIGHT, fill=TKNTR.Y)
 
         self._histText = tkrotext.ROText(self._histFrame, wrap=TKNTR.WORD,
-                         takefocus=False,
-                         height=10, yscrollcommand=self._histScrl.set)
+                                         takefocus=False,
+                                         height=10,
+                                         yscrollcommand=self._histScrl.set)
 # (use if just TKNTR.Text) state=TKNTR.DISABLED, takefocus=False,
 #                        exportselection=True is the default
         self._histText.pack(side=TKNTR.TOP, fill=TKNTR.X, expand=True)
@@ -114,7 +114,6 @@ class MsgIOWidget(TKNTR.Frame):
         # At very end of ctor, add the init text to our history
         self._appendToHistory(text)
 
-
     def _lblDblClk(self, event=None):
         if self._hasHistory:
             # change the button appearance
@@ -122,7 +121,6 @@ class MsgIOWidget(TKNTR.Frame):
             # and then act as if it was clicked
             self._expand()
 
-
     def _expand(self):
         ism = self._histFrame.winfo_ismapped()
         if ism: # need to collapse
@@ -136,7 +134,6 @@ class MsgIOWidget(TKNTR.Frame):
             if self._hasHistory:
                 self._histText.see(TKNTR.END)
 
-
     def updateIO(self, text=""):
         """ Update the text portion of the scrolling canvas """
         # Update the class variable with the latest text, and append the
@@ -145,11 +142,10 @@ class MsgIOWidget(TKNTR.Frame):
         self._msgLabelVar.set(text)
         # this is a little debugging "easter egg"
         if text.find('long debug line') >=0:
-           self.updateIO('and now we are going to talk and talk for a while'+\
+           self.updateIO('and now we are going to talk and talk for a while'+
                          ' about nothing at all because we want a lot of text')
         self._nowFrame.update_idletasks()
 
-
     def readline(self):
         """ Set focus to the entry widget and return it's contents """
         # Find what had focus up to this point
@@ -192,12 +188,10 @@ class MsgIOWidget(TKNTR.Frame):
         # return the answer - important to have the "\n" on it
         return ans+"\n"
 
-
     def _enteredText(self, event=None):
         self._entryTyping.set(False) # end the waiting
         self._expBttn.focus_set()
 
-
     def _appendToHistory(self, txt):
         # sanity check - need no blank lines in the history
         if len(txt.strip()) < 1:
@@ -224,47 +218,3 @@ class MsgIOWidget(TKNTR.Frame):
 
         # finally, make sure expand/collapse button is enabled now
         self._expBttn.configure(state = TKNTR.NORMAL)
-
-
-# Test the above class
-if __name__ == '__main__':
-
-    import sys, time
-
-    m = None
-
-    def quit():
-        sys.exit()
-
-    def clicked():
-        m.updateIO("Clicked at "+time.asctime())
-
-    def ask():
-        m.updateIO("Type something in:")
-        out = m.readline()
-
-    # create the initial Tk window and immediately withdraw it
-    irafutils.init_tk_default_root()
-
-    # make our test window
-    top = TKNTR.Toplevel()
-    f = TKNTR.Frame(top, width=500, height=300)
-    b = TKNTR.Button(f, text='Click Me', command=clicked)
-    b.pack(side=TKNTR.LEFT, fill=TKNTR.X, expand=1)
-    q = TKNTR.Button(f, text='Buh-Bye', command=quit)
-    q.pack(side=TKNTR.LEFT)
-    f.pack(side=TKNTR.TOP, fill=TKNTR.X) # , expand=1)
-    p = TKNTR.Button(top, text='Prompt Me', command=ask)
-    p.pack(side=TKNTR.TOP, fill=TKNTR.X, expand=1)
-    fill = TKNTR.Frame(top, height=200, bg="green")
-    fill.pack(side=TKNTR.TOP, fill=TKNTR.BOTH, expand=1)
-    m = MsgIOWidget(top, 500, "Tiptop")
-    m.pack(side=TKNTR.BOTTOM, fill=TKNTR.X)
-    for i in range(10):
-        t = "Text " + str(i)
-        m.updateIO(t)
-    m.updateIO("What is your quest?")
-    inputValue = m.readline()
-
-    # start
-    top.mainloop()
