@@ -1,24 +1,25 @@
-"""pyrafTk.py: modify Tkinter root to print short PyRAF tracebacks
+"""pyrafTk.py: modify tkinter root to print short PyRAF tracebacks
 
-$Id: pyrafTk.py 1463 2011-06-24 22:58:30Z stsci_embray $
+$Id$
 
 R. L. White, 2000 November 17
 """
 from __future__ import division # confidence high
 
-import sys, Tkinter
+import sys
+import Tkinter as TKNTR # requires 2to3
 import wutil
 
-class _PyrafTk(Tkinter.Tk):
+class _PyrafTk(TKNTR.Tk):
 
     """Modified Tk class that prints short pyraf tracebacks"""
 
     def __init__(self, function):
         self._pyraf_showtraceback = function
-        Tkinter.Tk.__init__(self)
+        TKNTR.Tk.__init__(self)
 
     def report_callback_exception(self, exc, val, tb):
-        sys.stderr.write("Exception in Tkinter callback\n")
+        sys.stderr.write("Exception in tkinter callback\n")
         sys.last_type = exc
         sys.last_value = val
         sys.last_traceback = tb
@@ -30,9 +31,9 @@ def setTkErrorHandler(function):
     If Tk root already exists, this function has no effect.
     """
 
-    if Tkinter._default_root is None and wutil.hasGraphics:
+    if TKNTR._default_root is None and wutil.hasGraphics:
         try:
             root = _PyrafTk(function)
             root.withdraw()
-        except Tkinter.TclError:
+        except TKNTR.TclError:
             pass
