@@ -854,64 +854,3 @@ class RedirProcess(Subprocess):
                 sys.stderr.flush()
                 self.die()
                 break
-
-
-#############################################################################
-#####                           Test                                    #####
-#############################################################################
-
-def test(fout = sys.stdout):
-    fout.write("Starting test ...\n")
-    assert hasattr(fout, 'write'), "Input not a file object: "+str(fout)
-    print "\tOpening subprocess (4 Jan 2017):"
-    p = Subprocess('cat', expire_noisily=1)        # set to expire noisily...
-    print p
-    print "\tOpening bogus subprocess, should fail:"
-    try:
-        # grab stderr just to make sure the error message still appears
-        b = Subprocess('/', 1, expire_noisily=1)
-        assert b.wait(1) == True, 'How is this still alive after 1 sec?'
-    except SubprocessError:
-        print "\t...yep, it failed."
-    print '\tWrite, then read, two newline-terminated lines, using readline:'
-    p.write('first full line written\n')
-    p.write('second\n')
-    x = p.readline(); print repr(x)
-    y = p.readline(); print repr(y)
-    assert x == tobytes('first full line written\n'), 'was: "'+str(x)+'"'
-    assert y == tobytes('second\n'), 'was: "'+str(y)+'"'
-    print '\tThree lines, last sans newline, read using combination:'
-    p.write('first\n'); p.write('second\n'); p.write('third, (no cr)')
-    print '\tFirst line via readline:'
-    x = p.readline()
-    assert x == tobytes('first\n'), 'was: "'+str(x)+'"'
-    print '\tRest via readPendingChars:'
-    time.sleep(1) # seems like we are sometimes too fast for the subproc
-    y = p.readPendingChars()
-    # Temporarily disable full compliance on this next one. Re-evaluating test
-    # driver in general.  But allow to pass here to exercise rest of tests.
-#   assert y == tobytes('second\nthird, (no cr)'), 'was: "'+str(y)+'"'
-    assert y.startswith(tobytes('second\n')), 'was: "'+str(y)+'"'
-    print "\tStopping then continuing subprocess (verbose):"
-    junk = p.readPendingChars() # discard any data left over from previous test
-    # verbose stop
-    assert p.stop(1), 'Stop seems to have failed!'
-    print '\tWriting line while subprocess is paused...'
-    p.write('written while subprocess paused\n')
-    print '\tNonblocking read of paused subprocess (should be empty):'
-    x = p.readPendingChars()
-    assert len(x)==0, 'should have been empty, but had: "'+str(x)+'"'
-    print '\tContinuing subprocess (verbose):'
-    # verbose continue
-    assert p.cont(1), 'Continue seems to have failed! Probably lost subproc...'
-    print '\tReading accumulated line, blocking read:'
-    x = p.readline()
-    assert x == tobytes('written while subprocess paused\n'),'was: "'+str(x)+'"'
-    print "\tDeleting subproc (pid "+str(p.pid)+"), which was to die noisily:"
-    del p
-    print "\tTest Successful!"
-    fout.write("Finished Test Successfully!\n")
-    return True
-
-if __name__ == "__main__":
-    test()
