@@ -1,10 +1,10 @@
 """Contains python routines to do special Window manipulations not
-possible in Tkinter.
+possible in tkinter.
 These are python stubs that are overloaded by a c version implementations.
 If the c versions do not exist, then these routines will do nothing
 
 
-$Id: wutil.py 2119 2013-12-31 20:44:39Z sontag $
+$Id$
 """
 from __future__ import division # confidence high
 
@@ -43,13 +43,11 @@ WUTIL_ON_WIN = sys.platform.startswith('win')
 # WUTIL_USING_X: default to using X on most platforms, tho surely not on windows
 WUTIL_USING_X = not WUTIL_ON_WIN
 
-# More on WUTIL_USING_X: for now we support both versions (X or Aqua) on OSX
+# More on this for OSX: for now we support both versions (X or Aqua) on OSX
+# Allow environment variable so any user can force their preference.
 if WUTIL_ON_MAC and not _skipDisplay:
-    if 'PYRAF_WUTIL_USING_AQUA' in os.environ:
-        WUTIL_USING_X = False
-    else:
-        # Do this check for them; look at the python binaries - are they X11-linked?
-        WUTIL_USING_X = capable.which_darwin_linkage() == "x11"
+    # default to aqua as it is the 98% case now (post v2.1.9), X11 users will need the env. var
+    WUTIL_USING_X = 'PYRAF_WUTIL_USING_X' in os.environ
 
 # Experimental new (2012) mode some have requested (OSX mostly) where all
 # graphics windows drawn are popped to the foreground and left there with
@@ -85,7 +83,7 @@ try:
         def getWindowIdZero(): return 0
         getFocalWindowID = getWindowIdZero
 
-        # If on OSX, use aqutil
+        # If on OSX w/out X11, use aqutil
         if WUTIL_ON_MAC and not _skipDisplay: # as opposed to the PC (future?)
             try:
                 import aqutil
@@ -96,7 +94,7 @@ try:
             except:
                 _has_aqutil = 0
                 print "Could not import aqutil, please see the online PyRAF FAQ"
-                print "http://www.stsci.edu/institute/software_hardware/pyraf/pyraf_faq#5.13"
+                print "http://www.stsci.edu/institute/software_hardware/pyraf/pyraf_faq#2.6"
 
 except ImportError:
     _has_xutil = 0 # Unsuccessful init of XWindow
@@ -508,7 +506,10 @@ def dumpspecs(outstream = None, skip_volatiles = False):
        pass
 
     out = "python exec = "+str(sys.executable)
-    out += "\npython ver = "+sys.version.split()[0]
+    if skip_volatiles:
+        out += "\npython ver = "+'.'.join([str(v) for v in sys.version_info[0:2]])
+    else:
+        out += "\npython ver = "+'.'.join([str(v) for v in sys.version_info[0:3]])
     out += "\nplatform = "+str(sys.platform)
     if not skip_volatiles:
         out += "\nPyRAF ver = "+pyrver
@@ -524,20 +525,24 @@ def dumpspecs(outstream = None, skip_volatiles = False):
 
     if not capable.OF_GRAPHICS:
         if hasattr(capable, 'TKINTER_IMPORT_FAILED'):
-            out += "\nTkinter import failed."
+            out += "\ntkinter import failed."
         else:
-            out += "\nTkinter use unattempted."
+            out += "\ntkinter use unattempted."
     else:
-        out += "\nTclVersion = "+str(capable.Tkinter.TclVersion)
-        out += "\nTkVersion = "+str(capable.Tkinter.TkVersion)
+        out += "\nTclVersion = "+str(capable.TKNTR.TclVersion)
+        out += "\nTkVersion = "+str(capable.TKNTR.TkVersion)
         out += "\nWUTIL_ON_MAC = "+str(WUTIL_ON_MAC)
         out += "\nWUTIL_ON_WIN = "+str(WUTIL_ON_WIN)
         out += "\nWUTIL_USING_X = "+str(WUTIL_USING_X)
-        out += "\nis_darwin_and_x = "+str(capable.is_darwin_and_x())
-        if WUTIL_ON_MAC:
-            out += "\nwhich_darwin_linkage = "+str(capable.which_darwin_linkage())
-        else:
-            out += "\nwhich_darwin_linkage = (not darwin)"
+        try: # the try/except handling here will be unneccessary after stsci.tools 3.4.2
+            out += "\nis_darwin_and_x = "+str(capable.is_darwin_and_x())
+            if WUTIL_ON_MAC:
+                out += "\nwhich_darwin_linkage = "+str(capable.which_darwin_linkage())
+                out += "\nwhich_darwin_linkage2 = "+str(capable.which_darwin_linkage(force_otool_check=True))
+            else:
+                out += "\nwhich_darwin_linkage = (not darwin)"
+        except Exception:
+            out += "\ndarwin linkage check threw exception"
         out += "\nskip display = "+str(_skipDisplay)
         out += "\nhas graphics = "+str(hasGraphics)
         out += "\nimported aqutil = "+str(bool(_has_aqutil))
@@ -596,16 +601,22 @@ if _skipDisplay:
         else:
             print "No graphics/display possible for this session."
             if hasattr(capable, 'TKINTER_IMPORT_FAILED'):
-                print "Tkinter import failed."
+                print "tkinter import failed."
 else:
     if _has_xutil or _has_aqutil:
         hasGraphics = focusController.hasGraphics
-    elif WUTIL_ON_MAC:
+    elif WUTIL_ON_MAC: # on a Mac but loaded no graphcs libs (aqutil/xutil)
         # Handle case where we are on the Mac with no X and no PyObjc.  We can
         # still run, albeit without automatic mouse moving and focus jumping.
         hasGraphics = focusController.hasGraphics
         if hasGraphics:
-            print "\nLimited graphics available (aqutil not loaded)\n"
+            try: # the try/except handling here will be unneccessary after stsci.tools 3.4.2
+                if capable.which_darwin_linkage() == 'aqua':
+                    print "\nLimited graphics available on OSX (aqutil not loaded)\n"
+                else:
+                    print "\nLimited graphics available on OSX (xutil not loaded)\n"
+            except Exception:
+                print "\nLimited graphics available on OSX (library not loaded)\n"
     elif WUTIL_ON_WIN:
         hasGraphics = 1 # try this, tho VERY limited (epar only I guess)
         print "\nLimited graphics available on win32 platform\n"
